@@ -1,7 +1,6 @@
 from datetime import datetime
 from datetime import timedelta
 
-
 # input: stringa contenente una data in qualsiasi formato
 # output: oggetto datetime.datetime con la data corrispondente
 def str_to_datetime(date_string):
@@ -29,7 +28,7 @@ def str_to_datetime(date_string):
         try:
             res = datetime.strptime(date_string, format_)
             return res
-        except ValueError:
+        except ValueError as e:
             continue
     raise ValueError("Formato data non supportato ({})".format(date_string))
 
